# skills_network_authoring_jupyterlab_extension is now skillsnetwork-jupyter-extension

This package has been renamed. Use `pip install skillsnetwork-jupyter-extension` instead.

New package: https://pypi.org/project/skillsnetwork-jupyter-extension/
